## Title：EmitGCL: Early Metastatic cell Identification Tool based on Graph Contrastive Learning
**Note: This project is for internal testing purposes only. Do not use it in a production environment.**

MarsGT, We developed EmitGCL, a graph contrastive learning model that integrates metastatic knowledge to detect subtle differences in cell groups at primary and metastatic sites.
## Installation

### System Requirements

* Python 3.8.0 or higher

### Installation Steps
* Install the required dependencies using pip:
```bash
pip install -r requirements.txt
```
* use pip to install EmitGCL:
```bash
pip install EmitGCL
```
